@@ -19,7 +19,7 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 #include <stdexcept>
 
 #include "config.hpp"
-#include "filter.hpp"
+#include <metaproxy/filter.hpp>
 
 namespace mp = metaproxy_1;
 
