@@ -17,11 +17,10 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
 #include "config.hpp"
-#include "filter.hpp"
-#include "package.hpp"
+#include <metaproxy/filter.hpp>
+#include <metaproxy/package.hpp>
 
-#include "util.hpp"
-#include "xmlutil.hpp"
+#include <metaproxy/util.hpp>
 #include "filter_query_rewrite.hpp"
 
 #include <yaz/zgdu.h>
