@@ -23,7 +23,7 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 #include <iostream>
 #include <fstream>
 
-#include "util.hpp"
+#include <metaproxy/util.hpp>
 
 #define PLAINFILE_MAX_LINE 256
 
