@@ -19,7 +19,7 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 #ifndef ROUTER_FLEXML_HPP
 #define ROUTER_FLEXML_HPP
 
-#include "router.hpp"
+#include <metaproxy/router.hpp>
 
 #include "factory_filter.hpp"
 
@@ -43,11 +43,6 @@ namespace metaproxy_1
         ~RouterFleXML();
 
         virtual RoutePos *createpos() const;
-        class XMLError1 : public std::runtime_error {
-        public:
-            XMLError1(const std::string msg) :
-                std::runtime_error("XMLError : " + msg) {} ;
-        };
     private:
         boost::scoped_ptr<Rep> m_p;
     };
