@@ -18,7 +18,7 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
 #include <stdexcept>
 
-#include "session.hpp"
+#include <metaproxy/session.hpp>
 #include <boost/thread/mutex.hpp>
 
 #include "config.hpp"
