@@ -35,7 +35,7 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 #include <iostream>
 #include <stdexcept>
 
-#include "util.hpp"
+#include <metaproxy/util.hpp>
 #include "pipe.hpp"
 
 #define BOOST_AUTO_TEST_MAIN
