@@ -17,7 +17,7 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
 #include "config.hpp"
-#include "util.hpp"
+#include <metaproxy/util.hpp>
 
 #include <yaz/odr.h>
 #include <yaz/pquery.h>
